@@ -26,8 +26,9 @@ import (
 
 	"github.com/tektoncd/triggers/pkg/interceptors/server"
 	"go.uber.org/zap"
-	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/rest"
+	secretInformer "knative.dev/pkg/client/injection/kube/informers/core/v1/secret"
+	"knative.dev/pkg/injection"
 	"knative.dev/pkg/logging"
 	"knative.dev/pkg/signals"
 )
@@ -49,10 +50,7 @@ func main() {
 		log.Fatalf("Failed to build config: %v", err)
 	}
 
-	kubeClient, err := kubernetes.NewForConfig(clusterConfig)
-	if err != nil {
-		log.Fatalf("Failed to get the Kubernetes client set: %v", err)
-	}
+	ctx, startInformer := injection.EnableInjectionOrDie(ctx, clusterConfig)
 
 	zap, err := zap.NewProduction()
 	if err != nil {
@@ -66,13 +64,17 @@ func main() {
 		}
 	}()
 
-	service, err := server.NewWithCoreInterceptors(kubeClient, logger)
+	secretLister := secretInformer.Get(ctx).Lister()
+	service, err := server.NewWithCoreInterceptors(secretLister, logger)
 	if err != nil {
 		log.Printf("failed to initialize core interceptors: %s", err)
 		return
 	}
+	startInformer()
+
 	mux := http.NewServeMux()
 	mux.Handle("/", service)
+	mux.HandleFunc("/ready", handler)
 
 	srv := &http.Server{
 		Addr: fmt.Sprintf(":%d", Port),
@@ -90,3 +92,7 @@ func main() {
 		logger.Fatalf("failed to start interceptors service: %v", err)
 	}
 }
+
+func handler(w http.ResponseWriter, r *http.Request) {
+	w.WriteHeader(http.StatusOK)
+}
