@@ -22,6 +22,7 @@ import (
 
 	pipelinev1 "github.com/tektoncd/pipeline/pkg/apis/pipeline/v1alpha1"
 	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1beta1"
+	"github.com/tektoncd/triggers/pkg/apis/triggers"
 	"github.com/tektoncd/triggers/pkg/apis/triggers/v1alpha1"
 	"github.com/tektoncd/triggers/test"
 	corev1 "k8s.io/api/core/v1"
@@ -102,6 +103,20 @@ func Test_EventListenerValidate(t *testing.T) {
 				}},
 			},
 		},
+	}, {
+		name: "Valid EventListener with Annotation",
+		el: &v1alpha1.EventListener{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:        "name",
+				Namespace:   "namespace",
+				Annotations: map[string]string{triggers.PayloadValidationAnnotation: "true"},
+			},
+			Spec: v1alpha1.EventListenerSpec{
+				Triggers: []v1alpha1.EventListenerTrigger{{
+					TriggerRef: "tt",
+				}},
+			},
+		},
 	}, {
 		name: "Valid EventListener with TriggerBinding",
 		el: &v1alpha1.EventListener{
@@ -486,7 +501,7 @@ func Test_EventListenerValidate(t *testing.T) {
 					Bindings: []*v1alpha1.EventListenerBinding{{
 						Ref:        "tb",
 						Kind:       v1alpha1.NamespacedTriggerBindingKind,
-						APIVersion: "v1alpha1", // TODO: APIVersions seem wrong?
+						APIVersion: "v1alpha1",
 					}},
 					Template: &v1alpha1.EventListenerTemplate{
 						Spec: &v1alpha1.TriggerTemplateSpec{
@@ -557,6 +572,20 @@ func TestEventListenerValidate_error(t *testing.T) {
 				}},
 			},
 		},
+	}, {
+		name: "Invalid Annotation value",
+		el: &v1alpha1.EventListener{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:        "name",
+				Namespace:   "namespace",
+				Annotations: map[string]string{triggers.PayloadValidationAnnotation: "xyz"},
+			},
+			Spec: v1alpha1.EventListenerSpec{
+				Triggers: []v1alpha1.EventListenerTrigger{{
+					TriggerRef: "tt",
+				}},
+			},
+		},
 	}, {
 		name: "TriggerBinding with no ref or spec",
 		el: &v1alpha1.EventListener{
@@ -946,27 +975,6 @@ func TestEventListenerValidate_error(t *testing.T) {
 				}},
 			},
 		},
-	}, {
-		name: "user specify invalid deprecated replicas",
-		el: &v1alpha1.EventListener{
-			ObjectMeta: metav1.ObjectMeta{
-				Name:      "name",
-				Namespace: "namespace",
-			},
-			Spec: v1alpha1.EventListenerSpec{
-				Triggers: []v1alpha1.EventListenerTrigger{{
-					Template: &v1alpha1.EventListenerTemplate{
-						Ref: ptr.String("tt"),
-					},
-				}},
-				DeprecatedReplicas: ptr.Int32(-1),
-				Resources: v1alpha1.Resources{
-					KubernetesResource: &v1alpha1.KubernetesResource{
-						Replicas: ptr.Int32(-1),
-					},
-				},
-			},
-		},
 	}, {
 		name: "user specify invalid replicas",
 		el: &v1alpha1.EventListener{
