@@ -31,6 +31,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/tektoncd/triggers/pkg/apis/triggers"
 	"knative.dev/pkg/ptr"
 
 	"k8s.io/client-go/kubernetes"
@@ -39,7 +40,8 @@ import (
 	"github.com/google/go-cmp/cmp/cmpopts"
 	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1alpha1"
 	triggersv1 "github.com/tektoncd/triggers/pkg/apis/triggers/v1alpha1"
-	eventReconciler "github.com/tektoncd/triggers/pkg/reconciler/v1alpha1/eventlistener"
+	eventReconciler "github.com/tektoncd/triggers/pkg/reconciler/eventlistener"
+	"github.com/tektoncd/triggers/pkg/reconciler/eventlistener/resources"
 	"github.com/tektoncd/triggers/pkg/sink"
 	bldr "github.com/tektoncd/triggers/test/builder"
 	corev1 "k8s.io/api/core/v1"
@@ -48,7 +50,6 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/fields"
 	"k8s.io/apimachinery/pkg/runtime"
-	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/tools/clientcmd"
 	"k8s.io/client-go/tools/portforward"
 	"k8s.io/client-go/transport/spdy"
@@ -57,9 +58,9 @@ import (
 )
 
 const (
-	resourceLabel = triggersv1.GroupName + triggersv1.EventListenerLabelKey
-	triggerLabel  = triggersv1.GroupName + triggersv1.TriggerLabelKey
-	eventIDLabel  = triggersv1.GroupName + triggersv1.EventIDLabelKey
+	resourceLabel = triggers.GroupName + triggers.EventListenerLabelKey
+	triggerLabel  = triggers.GroupName + triggers.TriggerLabelKey
+	eventIDLabel  = triggers.GroupName + triggers.EventIDLabelKey
 
 	examplePRJsonFilename = "pr.json"
 )
@@ -241,7 +242,7 @@ func TestEventListenerCreate(t *testing.T) {
 		&rbacv1.ClusterRole{
 			ObjectMeta: metav1.ObjectMeta{Name: "my-role"},
 			Rules: []rbacv1.PolicyRule{{
-				APIGroups: []string{triggersv1.GroupName},
+				APIGroups: []string{triggers.GroupName},
 				Resources: []string{"clustertriggerbindings", "eventlisteners", "clusterinterceptors", "triggerbindings", "triggertemplates", "triggers"},
 				Verbs:     []string{"get", "list", "watch"},
 			}, {
@@ -380,7 +381,7 @@ func TestEventListenerCreate(t *testing.T) {
 		},
 	}
 
-	labelSelector := fields.SelectorFromSet(eventReconciler.GenerateResourceLabels(el.Name, eventReconciler.DefaultStaticResourceLabels)).String()
+	labelSelector := fields.SelectorFromSet(resources.GenerateLabels(el.Name, resources.DefaultStaticResourceLabels)).String()
 	// Grab EventListener sink pods
 	sinkPods, err := c.KubeClient.CoreV1().Pods(namespace).List(context.Background(), metav1.ListOptions{LabelSelector: labelSelector})
 	if err != nil {
@@ -388,7 +389,7 @@ func TestEventListenerCreate(t *testing.T) {
 	}
 
 	// ElPort forward sink pod for http request
-	portString := strconv.Itoa(8000)
+	portString := strconv.Itoa(8080)
 	podName := sinkPods.Items[0].Name
 	stopChan, errChan := make(chan struct{}, 1), make(chan error, 1)
 
@@ -486,60 +487,6 @@ func TestEventListenerCreate(t *testing.T) {
 		}
 	}
 
-	// Now let's override auth at the trigger level and make sure we get a permission problem
-
-	// create SA/secret with insufficient permissions to set at trigger level
-	userWithoutPermissions := "user-with-no-permissions"
-	triggerSA := &corev1.ServiceAccount{
-		ObjectMeta: metav1.ObjectMeta{
-			Name:      userWithoutPermissions,
-			Namespace: namespace,
-			UID:       types.UID(userWithoutPermissions),
-		},
-	}
-
-	_, err = c.KubeClient.CoreV1().ServiceAccounts(namespace).Create(context.Background(), triggerSA, metav1.CreateOptions{})
-	if err != nil {
-		t.Fatalf("Error creating trigger SA: %s", err.Error())
-	}
-
-	if err := WaitFor(func() (bool, error) {
-		el, err := c.TriggersClient.TriggersV1alpha1().EventListeners(namespace).Get(context.Background(), el.Name, metav1.GetOptions{})
-		if err != nil {
-			return false, nil
-		}
-		for i, trigger := range el.Spec.Triggers {
-			trigger.ServiceAccountName = userWithoutPermissions
-			el.Spec.Triggers[i] = trigger
-		}
-		_, err = c.TriggersClient.TriggersV1alpha1().EventListeners(namespace).Update(context.Background(), el, metav1.UpdateOptions{})
-		if err != nil {
-			return false, nil
-		}
-		return true, nil
-	}); err != nil {
-		t.Fatalf("Failed to update EventListener for trigger auth test: %s", err)
-	}
-
-	// Verify the EventListener is ready with the new update
-	if err := WaitFor(eventListenerReady(t, c, namespace, el.Name)); err != nil {
-		t.Fatalf("EventListener not ready after trigger auth update: %s", err)
-	}
-	// Send POST request to EventListener sink
-	req, err = http.NewRequest("POST", fmt.Sprintf("http://127.0.0.1:%s", portString), bytes.NewBuffer(eventBodyJSON))
-	if err != nil {
-		t.Fatalf("Error creating POST request for trigger auth: %s", err)
-	}
-	req.Header.Add("Content-Type", "application/json")
-	resp, err = http.DefaultClient.Do(req)
-	if err != nil {
-		t.Fatalf("Error sending POST request for trigger auth: %s", err)
-	}
-
-	if resp.StatusCode != http.StatusUnauthorized && resp.StatusCode != http.StatusForbidden {
-		t.Errorf("sink did not return 401/403 response. Got status code: %d", resp.StatusCode)
-	}
-
 	// now set the trigger SA to the original one, should not get a 401/403
 	if err := WaitFor(func() (bool, error) {
 		el, err := c.TriggersClient.TriggersV1alpha1().EventListeners(namespace).Get(context.Background(), el.Name, metav1.GetOptions{})
